==> scipion_em_cryodrgn-3.7-py3-none-any.whl: cryodrgn/bibtex.py <==
# coding: utf-8
# **************************************************************************
# *
# * Authors:     Grigory Sharov (gsharov@mrc-lmb.cam.ac.uk)
# *
# * MRC Laboratory of Molecular Biology (MRC-LMB)
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 3 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************
"""

@article{Kinman2022,
  doi = {10.1101/2022.08.09.503342},
  url = {https://doi.org/10.1101/2022.08.09.503342},
  year = {2022},
  month = {aug},
  publisher = {Cold Spring Harbor Laboratory},
  author = {Laurel F. Kinman and Barrett M. Powell and Ellen D. Zhong and Bonnie Berger and Joseph H. Davis},
  title = {Uncovering structural ensembles from single particle cryo-{EM} data using {cryoDRGN}}
}

@article{Zhong2021,
 doi = {10.1038/s41592-020-01049-4},
 year = 2021,
 month = {feb},
 volume = {18},
 number = {2},
 pages = {176--185},
 author = {Ellen D. Zhong and Tristan Bepler and Bonnie Berger and Joseph H. Davis},
 title = {{CryoDRGN}: reconstruction of heterogeneous cryo-{EM} structures using neural networks},
 journal = {Nature Methods}
}

@article{Zhong2020,
 title={Reconstructing continuous distributions of 3D protein structure from cryo-EM images.},
 author={Zhong, Ellen D. and Bepler, Tristan and Davis, Joseph H. and Berger, Bonnie},
 journal={ICLR},
 volume={0},
 number={0},
 pages={0},
 year={2020},
 doi = {https://arxiv.org/abs/1909.05215}
}
"""

==> scipion_em_cryodrgn-3.10-py3-none-any.whl: cryodrgn/bibtex.py <==
# coding: utf-8
# **************************************************************************
# *
# * Authors:     Grigory Sharov (gsharov@mrc-lmb.cam.ac.uk)
# *
# * MRC Laboratory of Molecular Biology (MRC-LMB)
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 3 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************
"""

@article{Zhong2021b,
  author    = {Zhong, Ellen D. and Lerer, Adam and Davis, Joseph H. and Berger, Bonnie},
  title     = {CryoDRGN2: Ab Initio Neural Reconstruction of 3D Protein Structures From Real Cryo-EM Images},
  booktitle = {Proceedings of the IEEE/CVF International Conference on Computer Vision (ICCV)},
  month     = {October},
  year      = {2021},
  pages     = {4066-4075},
  url       = {https://openaccess.thecvf.com/content/ICCV2021/html/Zhong_CryoDRGN2_Ab_Initio_Neural_Reconstruction_of_3D_Protein_Structures_From_ICCV_2021_paper.html}
}

@article{Kinman2022,
  doi = {https://dx.doi.org/10.1101/2022.08.09.503342},
  year = {2022},
  month = {aug},
  publisher = {Cold Spring Harbor Laboratory},
  author = {Laurel F. Kinman and Barrett M. Powell and Ellen D. Zhong and Bonnie Berger and Joseph H. Davis},
  title = {Uncovering structural ensembles from single particle cryo-{EM} data using {cryoDRGN}}
}

@article{Zhong2021,
 doi = {https://dx.doi.org/10.1038/s41592-020-01049-4},
 year = 2021,
 month = {feb},
 volume = {18},
 number = {2},
 pages = {176--185},
 author = {Ellen D. Zhong and Tristan Bepler and Bonnie Berger and Joseph H. Davis},
 title = {{CryoDRGN}: reconstruction of heterogeneous cryo-{EM} structures using neural networks},
 journal = {Nature Methods}
}

@article{Zhong2020,
 title={Reconstructing continuous distributions of 3D protein structure from cryo-EM images.},
 author={Zhong, Ellen D. and Bepler, Tristan and Davis, Joseph H. and Berger, Bonnie},
 journal={ICLR},
 volume={0},
 number={0},
 pages={0},
 year={2020},
 doi = {https://arxiv.org/abs/1909.05215}
}
"""
